import * as cdk from 'aws-cdk-lib';
import * as constructs from 'constructs';
/**
 * Adds one team to the specified project. All members of the team share the same project access. To use this resource, the requesting API Key must have the Project User Admin role. This resource doesn't require the API Key to have an Access List.
 *
 * @schema CfnTeamsProps
 */
export interface CfnTeamsProps {
    /**
     * The profile is defined in AWS Secret manager. See [Secret Manager Profile setup](../../../examples/profile-secret.yaml).
     *
     * @schema CfnTeamsProps#Profile
     */
    readonly profile?: string;
    /**
     * One or more organization- or project-level roles to assign to the MongoDB Cloud user.
     *
     * @schema CfnTeamsProps#RoleNames
     */
    readonly roleNames?: CfnTeamsPropsRoleNames[];
    /**
     * Unique 24-hexadecimal character string that identifies the team.
     *
     * @schema CfnTeamsProps#OrgId
     */
    readonly orgId?: string;
    /**
     * Unique 24-hexadecimal character string that identifies the project.
     *
     * @schema CfnTeamsProps#ProjectId
     */
    readonly projectId?: string;
    /**
     * Unique 24-hexadecimal character string that identifies the team.
     *
     * @schema CfnTeamsProps#Name
     */
    readonly name?: string;
    /**
     * One or more organization- or project-level roles to assign to the MongoDB Cloud user.
     *
     * @schema CfnTeamsProps#Usernames
     */
    readonly usernames?: string[];
}
/**
 * Converts an object of type 'CfnTeamsProps' to JSON representation.
 */
export declare function toJson_CfnTeamsProps(obj: CfnTeamsProps | undefined): Record<string, any> | undefined;
/**
 * @schema CfnTeamsPropsRoleNames
 */
export declare enum CfnTeamsPropsRoleNames {
    /** GROUP_CLUSTER_MANAGER */
    GROUP_CLUSTER_MANAGER = "GROUP_CLUSTER_MANAGER",
    /** GROUP_DATA_ACCESS_ADMIN */
    GROUP_DATA_ACCESS_ADMIN = "GROUP_DATA_ACCESS_ADMIN",
    /** GROUP_DATA_ACCESS_READ_ONLY */
    GROUP_DATA_ACCESS_READ_ONLY = "GROUP_DATA_ACCESS_READ_ONLY",
    /** GROUP_DATA_ACCESS_READ_WRITE */
    GROUP_DATA_ACCESS_READ_WRITE = "GROUP_DATA_ACCESS_READ_WRITE",
    /** GROUP_OWNER */
    GROUP_OWNER = "GROUP_OWNER",
    /** GROUP_READ_ONLY */
    GROUP_READ_ONLY = "GROUP_READ_ONLY"
}
/**
 * A CloudFormation `MongoDB::Atlas::Teams`
 *
 * @cloudformationResource MongoDB::Atlas::Teams
 * @stability external
 */
export declare class CfnTeams extends cdk.CfnResource {
    /**
    * The CloudFormation resource type name for this resource class.
    */
    static readonly CFN_RESOURCE_TYPE_NAME = "MongoDB::Atlas::Teams";
    /**
     * Resource props.
     */
    readonly props: CfnTeamsProps;
    /**
     * Attribute `MongoDB::Atlas::Teams.TeamId`
     */
    readonly attrTeamId: string;
    /**
     * Attribute `MongoDB::Atlas::Teams.Users`
     */
    readonly attrUsers: any[];
    /**
     * Create a new `MongoDB::Atlas::Teams`.
     *
     * @param scope - scope in which this resource is defined
     * @param id    - scoped id of the resource
     * @param props - resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnTeamsProps);
}
